pub struct PlanCache { /* private fields */ }Expand description
FFT Plan Cache with configurable size limits and TTL
Implementations
Sourceimpl PlanCache
impl PlanCache
Sourcepub fn with_config(max_entries: usize, max_age: Duration) -> Self
pub fn with_config(max_entries: usize, max_age: Duration) -> Self
Create a new plan cache with custom settings
Sourcepub fn set_enabled(&self, enabled: bool)
pub fn set_enabled(&self, enabled: bool)
Enable or disable the cache
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Check if the cache is enabled
Sourcepub fn get_stats(&self) -> CacheStats
pub fn get_stats(&self) -> CacheStats
Get statistics about cache usage
Sourcepub fn track_plan_usage(&self, size: usize, forward: bool)
pub fn track_plan_usage(&self, size: usize, forward: bool)
Track FFT plan usage in the cache (OxiFFT backend)
Note: OxiFFT plans are managed globally via oxifft_plan_cache. This method provides tracking and statistics for plan usage.
Sourcepub fn precompute_common_sizes(&self, sizes: &[usize])
pub fn precompute_common_sizes(&self, sizes: &[usize])
Pre-populate cache with common sizes (OxiFFT backend)
Note: With OxiFFT, plans are created lazily and cached globally. This method tracks sizes for statistics purposes.