pub struct StreamingFftConfig {
pub fft_size: usize,
pub hop_size: usize,
pub window: WindowType,
}Expand description
Configuration for StreamingFft.
Fields
fft_size: usizeFFT window size. Must be a power of two and at least 2.
hop_size: usizeHop size (distance between successive analysis frames).
Must satisfy 1 <= hop_size <= fft_size.
window: WindowTypeWindow function applied to each frame before the FFT.